@@ -6,7 +6,7 @@ from builtins import object
 import logging
 import os
 import json
-import asyncio
+import tornado.ioloop
 
 from google.cloud import pubsub_v1
 
@@ -25,7 +25,7 @@ class BaseConsumer(object):
             sub=self.TOPIC_ID
         )
         self.instance = pubsub_v1.SubscriberClient()
-        self.loop = asyncio.get_event_loop()
+        self.loop = tornado.ioloop.IOLoop.current()
 
     def on_message(self, message_id, data, attributes, publish_time):
         pass
@@ -47,7 +47,7 @@ class BaseConsumer(object):
 
         self.instance.subscribe(self.subscription_name, handle_message)
 
-        self.loop.run_forever()
+        self.loop.start()
 
     def stop(self):
         self.loop.stop()
